==> apache-camel-3.22.2-src.zip: apache-camel-3.22.2/components/camel-jetty/src/test/java/org/apache/camel/component/jetty/rest/MyCustomHttpBinding.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jetty.rest;

import java.io.IOException;

import javax.servlet.http.HttpServletResponse;

import org.apache.camel.Exchange;
import org.apache.camel.Message;
import org.apache.camel.component.jetty.JettyRestHttpBinding;

public class MyCustomHttpBinding extends JettyRestHttpBinding {

    private String greeting;

    public MyCustomHttpBinding(String greeting) {
        this.greeting = greeting;
    }

    @Override
    public void doWriteResponse(Message message, HttpServletResponse response, Exchange exchange) throws IOException {
        message.setBody(greeting + message.getBody());
        super.doWriteResponse(message, response, exchange);
    }
}

==> apache-camel-4.2.0-src.zip: apache-camel-4.2.0/components/camel-jetty/src/test/java/org/apache/camel/component/jetty/rest/MyCustomHttpBinding.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jetty.rest;

import java.io.IOException;

import jakarta.servlet.http.HttpServletResponse;

import org.apache.camel.Exchange;
import org.apache.camel.Message;
import org.apache.camel.component.jetty.JettyRestHttpBinding;

public class MyCustomHttpBinding extends JettyRestHttpBinding {

    private String greeting;

    public MyCustomHttpBinding(String greeting) {
        this.greeting = greeting;
    }

    @Override
    public void doWriteResponse(Message message, HttpServletResponse response, Exchange exchange) throws IOException {
        message.setBody(greeting + message.getBody());
        super.doWriteResponse(message, response, exchange);
    }
}
